==> dry-1.2-sources.jar: hudson/plugins/dry/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.dry;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     *  1 new warning
     * 
     */
    public static String DRY_ResultAction_OneNewWarning() {
        return holder.format("DRY.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneNewWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneNewWarning");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_ProjectAction_Name() {
        return holder.format("DRY.ProjectAction.Name");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_ProjectAction_Name() {
        return new Localizable(holder, "DRY.ProjectAction.Name");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static String DRY_Publisher_Name() {
        return holder.format("DRY.Publisher.Name");
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static Localizable _DRY_Publisher_Name() {
        return new Localizable(holder, "DRY.Publisher.Name");
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * in {0} analysis files.
     * 
     */
    public static String DRY_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} analysis files.
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * in 1 analysis file.
     * 
     */
    public static String DRY_ResultAction_OneFile() {
        return holder.format("DRY.ResultAction.OneFile");
    }

    /**
     * in 1 analysis file.
     * 
     */
    public static Localizable _DRY_ResultAction_OneFile() {
        return new Localizable(holder, "DRY.ResultAction.OneFile");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static String DRY_ResultAction_HealthReportSingleItem() {
        return holder.format("DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static String DRY_Trend_Name() {
        return holder.format("DRY.Trend.Name");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static Localizable _DRY_Trend_Name() {
        return new Localizable(holder, "DRY.Trend.Name");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static String DRY_NewWarnings_Detail_header() {
        return holder.format("DRY.NewWarnings.Detail.header");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_NewWarnings_Detail_header() {
        return new Localizable(holder, "DRY.NewWarnings.Detail.header");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String DRY_ResultAction_OneNoHighScore() {
        return holder.format("DRY.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _DRY_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "DRY.ResultAction.OneNoHighScore");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_Detail_header() {
        return holder.format("DRY.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_Detail_header() {
        return new Localizable(holder, "DRY.Detail.header");
    }

    /**
     * New zero warnings highscore: no duplicate code warnings since {0} days!
     * 
     */
    public static String DRY_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no duplicate code warnings since {0} days!
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleHighScore", arg1);
    }

    /**
     *  1 warning
     * 
     */
    public static String DRY_ResultAction_OneWarning() {
        return holder.format("DRY.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneWarning");
    }

    /**
     * New zero warnings highscore: no duplicate code warnings since yesterday!
     * 
     */
    public static String DRY_ResultAction_OneHighScore() {
        return holder.format("DRY.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no duplicate code warnings since yesterday!
     * 
     */
    public static Localizable _DRY_ResultAction_OneHighScore() {
        return new Localizable(holder, "DRY.ResultAction.OneHighScore");
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static String DRY_Warning_Message(Object arg1) {
        return holder.format("DRY.Warning.Message", arg1);
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static Localizable _DRY_Warning_Message(Object arg1) {
        return new Localizable(holder, "DRY.Warning.Message", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String DRY_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("DRY.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _DRY_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String DRY_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String DRY_ResultAction_OneFixedWarning() {
        return holder.format("DRY.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneFixedWarning");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static String DRY_FixedWarnings_Detail_header() {
        return holder.format("DRY.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_FixedWarnings_Detail_header() {
        return new Localizable(holder, "DRY.FixedWarnings.Detail.header");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportNoItem() {
        return holder.format("DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String DRY_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleWarnings", arg1);
    }

}

==> dry-1.7-sources.jar: hudson/plugins/dry/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.dry;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     *  1 new warning
     * 
     */
    public static String DRY_ResultAction_OneNewWarning() {
        return holder.format("DRY.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneNewWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneNewWarning");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_ProjectAction_Name() {
        return holder.format("DRY.ProjectAction.Name");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_ProjectAction_Name() {
        return new Localizable(holder, "DRY.ProjectAction.Name");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static String DRY_Publisher_Name() {
        return holder.format("DRY.Publisher.Name");
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static Localizable _DRY_Publisher_Name() {
        return new Localizable(holder, "DRY.Publisher.Name");
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * in {0} analysis files.
     * 
     */
    public static String DRY_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} analysis files.
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * in 1 analysis file.
     * 
     */
    public static String DRY_ResultAction_OneFile() {
        return holder.format("DRY.ResultAction.OneFile");
    }

    /**
     * in 1 analysis file.
     * 
     */
    public static Localizable _DRY_ResultAction_OneFile() {
        return new Localizable(holder, "DRY.ResultAction.OneFile");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static String DRY_ResultAction_HealthReportSingleItem() {
        return holder.format("DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static String DRY_Trend_Name() {
        return holder.format("DRY.Trend.Name");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static Localizable _DRY_Trend_Name() {
        return new Localizable(holder, "DRY.Trend.Name");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static String DRY_NewWarnings_Detail_header() {
        return holder.format("DRY.NewWarnings.Detail.header");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_NewWarnings_Detail_header() {
        return new Localizable(holder, "DRY.NewWarnings.Detail.header");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String DRY_ResultAction_OneNoHighScore() {
        return holder.format("DRY.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _DRY_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "DRY.ResultAction.OneNoHighScore");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_Detail_header() {
        return holder.format("DRY.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_Detail_header() {
        return new Localizable(holder, "DRY.Detail.header");
    }

    /**
     * New zero warnings highscore: no duplicate code warnings for {0} days!
     * 
     */
    public static String DRY_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no duplicate code warnings for {0} days!
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleHighScore", arg1);
    }

    /**
     *  1 warning
     * 
     */
    public static String DRY_ResultAction_OneWarning() {
        return holder.format("DRY.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneWarning");
    }

    /**
     * New zero warnings highscore: no duplicate code warnings since yesterday!
     * 
     */
    public static String DRY_ResultAction_OneHighScore() {
        return holder.format("DRY.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no duplicate code warnings since yesterday!
     * 
     */
    public static Localizable _DRY_ResultAction_OneHighScore() {
        return new Localizable(holder, "DRY.ResultAction.OneHighScore");
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static String DRY_Warning_Message(Object arg1) {
        return holder.format("DRY.Warning.Message", arg1);
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static Localizable _DRY_Warning_Message(Object arg1) {
        return new Localizable(holder, "DRY.Warning.Message", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String DRY_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("DRY.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _DRY_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String DRY_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String DRY_ResultAction_OneFixedWarning() {
        return holder.format("DRY.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneFixedWarning");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static String DRY_FixedWarnings_Detail_header() {
        return holder.format("DRY.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_FixedWarnings_Detail_header() {
        return new Localizable(holder, "DRY.FixedWarnings.Detail.header");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportNoItem() {
        return holder.format("DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String DRY_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleWarnings", arg1);
    }

}
